slepc-3.18.0 2022-10-01
Report Typos and Errors

# NEPNLEIGSGetEPS

Retrieve the eigensolver object (EPS) associated to the nonlinear eigenvalue solver.

### Synopsis

    #include "slepcnep.h"
    PetscErrorCode NEPNLEIGSGetEPS(NEP nep,EPS *eps)

Not Collective

### Input Parameter

| nep | - nonlinear eigenvalue solver

### Output Parameter

| eps | - the eigensolver object

### See Also

NEPNLEIGSSetEPS()

### Level

advanced

### Location

src/nep/impls/nleigs/nleigs-fullb.c
Index of all NEP routines
Table of Contents for all manual pages
Index of all manual pages